@@ -631,7 +631,7 @@ static AOM_INLINE void update_palette_cdf(MacroBlockD *xd, const MbModeInfo *con
             update_cdf(fc->palette_y_size_cdf[palette_bsize_ctx], n - PALETTE_MIN_SIZE, PALETTE_SIZES);
         }
     }
-    uint32_t  intra_chroma_mode = blk_ptr->prediction_unit_array->intra_chroma_mode;
+    uint32_t  intra_chroma_mode = blk_ptr->intra_chroma_mode;
     const int uv_dc_pred        = intra_chroma_mode == UV_DC_PRED && is_chroma_reference(mi_row, mi_col, bsize, 1, 1);
 
     if (uv_dc_pred) {
@@ -672,19 +672,19 @@ static AOM_INLINE void sum_intra_stats(PictureControlSet *pcs, BlkStruct *blk_pt
     }
     if (av1_is_directional_mode(y_mode) && av1_use_angle_delta(bsize, pcs->ppcs->scs->intra_angle_delta)) {
         update_cdf(fc->angle_delta_cdf[y_mode - V_PRED],
-                   blk_ptr->prediction_unit_array[0].angle_delta[PLANE_TYPE_Y] + MAX_ANGLE_DELTA,
+                   blk_ptr->angle_delta[PLANE_TYPE_Y] + MAX_ANGLE_DELTA,
                    2 * MAX_ANGLE_DELTA + 1);
     }
     uint8_t sub_sampling_x = 1; // NM - subsampling_x is harcoded to 1 for 420 chroma sampling.
     uint8_t sub_sampling_y = 1; // NM - subsampling_y is harcoded to 1 for 420 chroma sampling.
     if (!is_chroma_reference(mi_row, mi_col, bsize, sub_sampling_x, sub_sampling_y))
         return;
-    const UvPredictionMode uv_mode     = blk_ptr->prediction_unit_array->intra_chroma_mode;
+    const UvPredictionMode uv_mode     = blk_ptr->intra_chroma_mode;
     const int              cfl_allowed = blk_geom->bwidth <= 32 && blk_geom->bheight <= 32;
     update_cdf(fc->uv_mode_cdf[cfl_allowed][y_mode], uv_mode, UV_INTRA_MODES - !cfl_allowed);
     if (uv_mode == UV_CFL_PRED) {
-        const int8_t  joint_sign = blk_ptr->prediction_unit_array->cfl_alpha_signs;
-        const uint8_t idx        = blk_ptr->prediction_unit_array->cfl_alpha_idx;
+        const int8_t  joint_sign = blk_ptr->cfl_alpha_signs;
+        const uint8_t idx        = blk_ptr->cfl_alpha_idx;
         update_cdf(fc->cfl_sign_cdf, joint_sign, CFL_JOINT_SIGNS);
         if (CFL_SIGN_U(joint_sign) != CFL_SIGN_ZERO) {
             AomCdfProb *cdf_u = fc->cfl_alpha_cdf[CFL_CONTEXT_U(joint_sign)];
@@ -701,7 +701,7 @@ static AOM_INLINE void sum_intra_stats(PictureControlSet *pcs, BlkStruct *blk_pt
         assert((uv_mode - UV_V_PRED) < DIRECTIONAL_MODES);
         assert((uv_mode - UV_V_PRED) >= 0);
         update_cdf(fc->angle_delta_cdf[uv_mode - UV_V_PRED],
-                   blk_ptr->prediction_unit_array[0].angle_delta[PLANE_TYPE_UV] + MAX_ANGLE_DELTA,
+                   blk_ptr->angle_delta[PLANE_TYPE_UV] + MAX_ANGLE_DELTA,
                    2 * MAX_ANGLE_DELTA + 1);
     }
     if (svt_aom_allow_palette(pcs->ppcs->frm_hdr.allow_screen_content_tools, bsize)) {
@@ -820,8 +820,8 @@ void svt_aom_update_stats(PictureControlSet *pcs, BlkStruct *blk_ptr, int mi_row
             }
             const MotionMode motion_allowed = pcs->ppcs->frm_hdr.is_motion_mode_switchable
                 ? svt_aom_motion_mode_allowed(pcs,
-                                              blk_ptr->prediction_unit_array[0].num_proj_ref,
-                                              blk_ptr->prediction_unit_array[0].overlappable_neighbors,
+                                              blk_ptr->num_proj_ref,
+                                              blk_ptr->overlappable_neighbors,
                                               bsize,
                                               mbmi->block_mi.ref_frame[0],
                                               mbmi->block_mi.ref_frame[1],
@@ -829,9 +829,9 @@ void svt_aom_update_stats(PictureControlSet *pcs, BlkStruct *blk_ptr, int mi_row
                 : SIMPLE_TRANSLATION;
             if (mbmi->block_mi.ref_frame[1] != INTRA_FRAME) {
                 if (motion_allowed == WARPED_CAUSAL) {
-                    update_cdf(fc->motion_mode_cdf[bsize], blk_ptr->prediction_unit_array[0].motion_mode, MOTION_MODES);
+                    update_cdf(fc->motion_mode_cdf[bsize], blk_ptr->motion_mode, MOTION_MODES);
                 } else if (motion_allowed == OBMC_CAUSAL) {
-                    update_cdf(fc->obmc_cdf[bsize], blk_ptr->prediction_unit_array[0].motion_mode == OBMC_CAUSAL, 2);
+                    update_cdf(fc->obmc_cdf[bsize], blk_ptr->motion_mode == OBMC_CAUSAL, 2);
                 }
             }
 
@@ -866,8 +866,7 @@ void svt_aom_update_stats(PictureControlSet *pcs, BlkStruct *blk_ptr, int mi_row
             }
         }
     }
-    if (inter_block && frm_hdr->interpolation_filter == SWITCHABLE &&
-        blk_ptr->prediction_unit_array[0].motion_mode != WARPED_CAUSAL &&
+    if (inter_block && frm_hdr->interpolation_filter == SWITCHABLE && blk_ptr->motion_mode != WARPED_CAUSAL &&
         !svt_aom_is_nontrans_global_motion_ec(
             mbmi->block_mi.ref_frame[0], mbmi->block_mi.ref_frame[1], blk_ptr->pred_mode, bsize, pcs->ppcs)) {
         update_filter_type_cdf(xd, mbmi, pcs->scs->seq_header.enable_dual_filter);
@@ -875,9 +874,8 @@ void svt_aom_update_stats(PictureControlSet *pcs, BlkStruct *blk_ptr, int mi_row
     if (inter_block && !seg_ref_active) {
         const PredictionMode mode = mbmi->block_mi.mode;
         MvReferenceFrame     rf[2];
-        av1_set_ref_frame(rf, blk_ptr->prediction_unit_array[0].ref_frame_type);
-        const int16_t mode_ctx = svt_aom_mode_context_analyzer(
-            blk_ptr->inter_mode_ctx[blk_ptr->prediction_unit_array[0].ref_frame_type], rf);
+        av1_set_ref_frame(rf, blk_ptr->ref_frame_type);
+        const int16_t mode_ctx = svt_aom_mode_context_analyzer(blk_ptr->inter_mode_ctx, rf);
         if (svt_aom_has_second_ref(mbmi)) {
             update_cdf(fc->inter_compound_mode_cdf[mode_ctx], INTER_COMPOUND_OFFSET(mode), INTER_COMPOUND_MODES);
         } else {
@@ -920,15 +918,15 @@ void svt_aom_update_stats(PictureControlSet *pcs, BlkStruct *blk_ptr, int mi_row
             } else if (mbmi->block_mi.mode == NEAREST_NEWMV || mbmi->block_mi.mode == NEAR_NEWMV) {
                 IntMv ref_mv = blk_ptr->predmv[1];
                 MV    mv;
-                mv.row = blk_ptr->prediction_unit_array[0].mv[1].y;
-                mv.col = blk_ptr->prediction_unit_array[0].mv[1].x;
+                mv.row = blk_ptr->mv[1].y;
+                mv.col = blk_ptr->mv[1].x;
                 av1_update_mv_stats(&mv, &ref_mv.as_mv, &fc->nmvc, allow_hp);
             } else if (mbmi->block_mi.mode == NEW_NEARESTMV || mbmi->block_mi.mode == NEW_NEARMV) {
                 IntMv ref_mv = blk_ptr->predmv[0];
 
                 MV mv;
-                mv.row = blk_ptr->prediction_unit_array[0].mv[0].y;
-                mv.col = blk_ptr->prediction_unit_array[0].mv[0].x;
+                mv.row = blk_ptr->mv[0].y;
+                mv.col = blk_ptr->mv[0].x;
                 av1_update_mv_stats(&mv, &ref_mv.as_mv, &fc->nmvc, allow_hp);
             }
         }
