@@ -400,10 +400,8 @@ EbErrorType pcs_update_param(PictureControlSet *pcs) {
     if ((is_16bit) || (scs->is_16bit_pipeline)) {
         svt_picture_buffer_desc_update(pcs->input_frame16bit, (EbPtr)&coeff_buffer_desc_init_data);
     }
-    if (svt_aom_get_enable_restoration(scs->static_config.enc_mode,
-                                       scs->static_config.enable_restoration_filtering,
-                                       scs->input_resolution,
-                                       scs->static_config.fast_decode)) {
+    if (svt_aom_get_enable_restoration(
+            scs->static_config.enc_mode, scs->static_config.enable_restoration_filtering, scs->input_resolution)) {
         set_restoration_unit_size(scs->max_input_luma_width, scs->max_input_luma_height, 1, 1, pcs->rst_info);
     }
     pcs->frame_width  = scs->max_input_luma_width;
@@ -495,11 +493,9 @@ static EbErrorType picture_control_set_ctor(PictureControlSet *object_ptr, EbPtr
     object_ptr->temp_lf_recon_pic_16bit           = (EbPictureBufferDesc *)NULL;
     object_ptr->temp_lf_recon_pic                 = (EbPictureBufferDesc *)NULL;
     object_ptr->scaled_input_pic                  = (EbPictureBufferDesc *)NULL;
-
     if (svt_aom_get_enable_restoration(init_data_ptr->enc_mode,
                                        init_data_ptr->static_config.enable_restoration_filtering,
-                                       init_data_ptr->input_resolution,
-                                       init_data_ptr->static_config.fast_decode)) {
+                                       init_data_ptr->input_resolution)) {
         set_restoration_unit_size(
             init_data_ptr->picture_width, init_data_ptr->picture_height, 1, 1, object_ptr->rst_info);
 
@@ -1060,6 +1056,7 @@ static EbErrorType picture_control_set_ctor(PictureControlSet *object_ptr, EbPtr
             }
         }
     }
+
     for (uint8_t is_islice = 0; is_islice <= 1; is_islice++) {
         for (uint8_t is_base = 0; is_base <= 1; is_base++) {
             disallow_4x4 = MIN(disallow_4x4, svt_aom_get_disallow_4x4(init_data_ptr->enc_mode, is_base));
@@ -1304,7 +1301,7 @@ static EbErrorType picture_parent_control_set_ctor(PictureParentControlSet *obje
 
     if (init_data_ptr->calculate_variance) {
         uint8_t block_count;
-        if (init_data_ptr->enable_adaptive_quantization == 1)
+        if (init_data_ptr->enable_adaptive_quantization == 1 || init_data_ptr->variance_octile)
             block_count = 85;
         else
             block_count = 1;
