@@ -164,19 +164,21 @@ struct PredictionUnit;
 
 typedef struct EbMdcLeafData {
     uint32_t mds_idx;
-    uint32_t tot_d1_blocks; // how many d1 bloks every parent square would have
-    bool     is_child; // does is it belong to the child depth(s); relative to PRED (the output of PD0)
+    // array containing all shapes to be tested for the current SQ block
+    Part shapes[PART_S];
+    // total number of shapes to test for the current SQ block
+    uint8_t tot_shapes;
+    bool    is_child; // does is it belong to the child depth(s); relative to PRED (the output of PD0)
 } EbMdcLeafData;
 
 typedef struct MdcSbData {
-    uint32_t      leaf_count;
-    EbMdcLeafData leaf_data_array[BLOCK_MAX_COUNT_SB_128];
-    Bool          split_flag[BLOCK_MAX_COUNT_SB_128];
-    uint8_t
-        consider_block[BLOCK_MAX_COUNT_SB_128]; // 0: do not encode, 1: current or parent depth(s), 2: child depth(s)
-    uint8_t refined_split_flag[BLOCK_MAX_COUNT_SB_128];
+    uint32_t       leaf_count;
+    EbMdcLeafData *leaf_data_array;
+    Bool          *split_flag;
+    uint8_t       *refined_split_flag;
+    // 0: do not encode, 1: current or parent depth(s), 2: child depth(s)
+    uint8_t *consider_block;
 } MdcSbData;
-
 /**************************************
  * Picture Control Set
  **************************************/
@@ -356,7 +358,8 @@ typedef struct PictureControlSet {
     uint8_t disallow_4x4_all_frames;
     uint8_t wm_level; // warped motion level
     uint8_t cand_reduction_level;
-    uint8_t nsq_level;
+    uint8_t nsq_geom_level;
+    uint8_t nsq_search_level;
     uint8_t txt_level;
     uint8_t tx_shortcut_level;
     uint8_t interpolation_search_level;
@@ -376,7 +379,6 @@ typedef struct PictureControlSet {
     uint8_t md_pme_level;
     uint8_t mds0_level;
     uint8_t pic_disallow_4x4; // disallow 4x4 at pic level
-    uint8_t pic_skip_pd0; // skip_pd0 at pic level
     uint8_t pic_disallow_below_16x16; // disallow_below_16x16 signal at pic level
     // depth_removal_level signal at the picture level
     uint8_t pic_depth_removal_level;
@@ -388,6 +390,7 @@ typedef struct PictureControlSet {
     Bool             pic_bypass_encdec;
     EncMode          enc_mode;
     InputCoeffLvl    coeff_lvl;
+    bool             me_dist_mod; // Whether or not to modulate the level of prediction tools using me-distortion
     int32_t          cdef_preset[MAX_TILE_CNTS][4];
     WienerInfo       wiener_info[MAX_TILE_CNTS][MAX_MB_PLANE];
     SgrprojInfo      sgrproj_info[MAX_TILE_CNTS][MAX_MB_PLANE];
@@ -434,6 +437,7 @@ typedef struct PictureControlSet {
     uint8_t    approx_inter_rate;
     uint8_t    skip_intra;
     PicVqCtrls vq_ctrls;
+    uint16_t   lambda_weight;
     // scaled input picture is only used in loop restoration for recon size is
     // different with input frame when reference scaling is enabled
     EbPictureBufferDesc *scaled_input_pic;
@@ -526,6 +530,8 @@ typedef struct TplControls {
     // the max precision for TPL subpel
     SUBPEL_FORCE_STOP
     subpel_depth;
+    // Specifies the subpel accuracy for diagonal position(s)
+    uint8_t subpel_diag_refinement;
 } TplControls;
 
 typedef struct {
@@ -844,7 +850,6 @@ typedef struct PictureParentControlSet {
     int8_t               is_gm_on; //-1 invalid, 1: gm on in one of the ref frames,  0:gm off for all ref frames
     uint16_t             me_processed_b64_count;
     EbHandle             me_processed_b64_mutex;
-    FirstPassData        firstpass_data;
     double               ts_duration;
     double               r0;
     // track pictures that are processd in two different TPL groups
@@ -949,15 +954,27 @@ typedef struct PictureParentControlSet {
     int32_t              film_grain_params_present; // todo (AN): Do we need this flag at picture level?
     int8_t               cdef_level;
     Bool                 enable_restoration; // TRUE if restoration filtering is enabled for the current frame
-    uint8_t              palette_level;
-    uint8_t              sc_class0;
-    uint8_t              sc_class1;
-    uint8_t              sc_class2;
-    SkipModeInfo         skip_mode_info;
-    uint64_t             picture_number_alt; // The picture number overlay includes all the overlay frames
-    uint8_t              is_alt_ref;
-    uint8_t              is_overlay;
+
+    uint8_t palette_level;
+
+    uint8_t sc_class0;
+
+    uint8_t sc_class1;
+
+    uint8_t sc_class2;
+
+    uint8_t sc_class3;
+
+    SkipModeInfo skip_mode_info;
+
+    uint64_t picture_number_alt; // The picture number overlay includes all the overlay frames
+
+    uint8_t is_alt_ref;
+
+    uint8_t is_overlay;
+
     struct PictureParentControlSet *overlay_ppcs_ptr;
+
     struct PictureParentControlSet *alt_ref_ppcs_ptr;
     int32_t                         noise_levels_log1p_fp16[MAX_MB_PLANE];
     int32_t                         pic_decision_reorder_queue_idx;
@@ -1056,27 +1073,19 @@ typedef struct PictureParentControlSet {
     bool         gm_pp_detected; //gm detection enabled at the pre-processing level
     CdefControls cdef_ctrls;
     // RC related variables
-    int                             q_low;
-    int                             q_high;
-    int                             loop_count;
-    int                             overshoot_seen;
-    int                             undershoot_seen;
-    int                             low_cr_seen;
-    uint64_t                        pcs_total_rate;
-    EbHandle                        pcs_total_rate_mutex;
-    int16_t                         first_pass_seg_total_count;
-    uint8_t                         first_pass_seg_column_count;
-    uint8_t                         first_pass_seg_row_count;
-    uint16_t                        first_pass_seg_acc;
-    EbHandle                        first_pass_done_semaphore;
-    EbHandle                        first_pass_mutex;
-    struct PictureParentControlSet *first_pass_ref_ppcs_ptr[2];
-    uint8_t                         first_pass_ref_count;
-    uint8_t                         first_pass_done;
-    uint8_t                         first_frame_in_minigop;
-    TplControls                     tpl_ctrls;
-    uint8_t                         tpl_is_valid;
-    EbHandle                        tpl_disp_mutex;
+    int         q_low;
+    int         q_high;
+    int         loop_count;
+    int         overshoot_seen;
+    int         undershoot_seen;
+    int         low_cr_seen;
+    uint64_t    pcs_total_rate;
+    EbHandle    pcs_total_rate_mutex;
+    uint8_t     first_pass_done;
+    uint8_t     first_frame_in_minigop;
+    TplControls tpl_ctrls;
+    uint8_t     tpl_is_valid;
+    EbHandle    tpl_disp_mutex;
     // uint32_t         input_type;
     int16_t  enc_dec_segment_row;
     uint16_t tile_group_index;
@@ -1131,8 +1140,11 @@ typedef struct PictureParentControlSet {
     uint32_t tf_ahd_error_to_central;
     // Average absolute histogram deviation of all frames in the TF window to the current (central) frame
     uint32_t tf_avg_ahd_error;
+    uint64_t tf_avg_luma;
     bool     tf_active_region_present;
     bool     seq_param_changed;
+    uint64_t norm_me_dist;
+    uint8_t  tpl_params_ready;
 } PictureParentControlSet;
 
 typedef struct TplDispResults {
@@ -1191,7 +1203,6 @@ typedef struct PictureControlSetInitData {
     uint8_t    enable_tpl_la;
     uint8_t    tpl_synth_size;
     uint8_t    in_loop_ois;
-    uint8_t    pass;
     uint32_t   rate_control_mode;
     Av1Common *av1_cm;
     uint16_t   init_max_block_cnt;
@@ -1201,19 +1212,14 @@ typedef struct PictureControlSetInitData {
     uint8_t enable_adaptive_quantization;
     uint8_t calc_hist;
     uint8_t tpl_lad_mg;
-    uint8_t skip_frame_first_pass;
-    uint8_t ipp_ds;
-    uint8_t bypass_blk_step;
-    uint8_t dist_ds;
-    uint8_t ipp_was_ds;
     uint8_t final_pass_preset;
-    uint8_t bypass_zz_check;
-    uint8_t use8blk;
-    uint8_t reduce_me_search;
     uint8_t input_resolution;
     uint8_t calculate_variance;
     Bool    is_scale;
     bool    rtc_tune;
+    Bool    enable_variance_boost;
+    uint8_t variance_boost_strength;
+    uint8_t variance_octile;
 } PictureControlSetInitData;
 
 typedef struct Av1Comp {
