@@ -44,13 +44,6 @@ EbErrorType svt_av1_verify_settings(SequenceControlSet *scs) {
         SVT_ERROR("Instance %u: EncoderMode must be in the range of [-1-%d]\n", channel_number + 1, MAX_ENC_PRESET);
         return_error = EB_ErrorBadParameter;
     }
-    if (config->enc_mode == MAX_ENC_PRESET) {
-        SVT_WARN(
-            "EncoderMode (preset): %d was developed for the sole purpose of debugging and or "
-            "running fast convex-hull encoding. This configuration should not be used for any "
-            "benchmarking or quality analysis\n",
-            MAX_ENC_PRESET);
-    }
     if (scs->max_input_luma_width < 64) {
         SVT_ERROR("Instance %u: Source Width must be at least 64\n", channel_number + 1);
         return_error = EB_ErrorBadParameter;
@@ -75,10 +68,12 @@ EbErrorType svt_av1_verify_settings(SequenceControlSet *scs) {
         SVT_ERROR("Instance %u: Multi-passes is not support with Low Delay mode \n", channel_number + 1);
         return_error = EB_ErrorBadParameter;
     }
+#if !SVT_AV1_CHECK_VERSION(2, 0, 0)
     if (config->vbr_bias_pct != 100) {
         SVT_WARN("Instance %u: The bias percentage is being ignored and will be deprecated in the up coming release \n",
                  channel_number + 1);
     }
+#endif
 
     if (config->maximum_buffer_size_ms < 20 || config->maximum_buffer_size_ms > 10000) {
         SVT_ERROR("Instance %u: The maximum buffer size must be between [20, 10000]\n", channel_number + 1);
@@ -183,6 +178,12 @@ EbErrorType svt_av1_verify_settings(SequenceControlSet *scs) {
         SVT_ERROR("VBR Rate control is currently not supported for SVT_AV1_PRED_LOW_DELAY_B, use CBR mode\n");
         return_error = EB_ErrorBadParameter;
     }
+    if (config->rate_control_mode == SVT_AV1_RC_MODE_CQP_OR_CRF && config->target_bit_rate != DEFAULT_TBR) {
+        SVT_ERROR("Instance %u: Target Bitrate only supported when --rc is  1/2 (VBR/CBR). Current --rc: %d\n",
+                  channel_number + 1,
+                  config->rate_control_mode);
+        return_error = EB_ErrorBadParameter;
+    }
 
     if (scs->max_input_luma_width > 16384) {
         SVT_ERROR("Instance %u: Source Width must be less than or equal to 16384\n", channel_number + 1);
@@ -535,7 +536,16 @@ EbErrorType svt_av1_verify_settings(SequenceControlSet *scs) {
             config->enable_dg);
         return_error = EB_ErrorBadParameter;
     }
-
+#if OPT_FAST_DECODE_LVLS
+    if (config->fast_decode < -1 || config->fast_decode > 3) {
+        SVT_ERROR(
+            "Instance %u: Invalid fast decode flag [-1 - 3, 0 for no decoder optimization], your "
+            "input: %d\n",
+            channel_number + 1,
+            config->fast_decode);
+        return_error = EB_ErrorBadParameter;
+    }
+#else
     if (config->fast_decode > 1) {
         SVT_ERROR(
             "Instance %u: Invalid fast decode flag [0 - 1, 0 for no decoder optimization], your "
@@ -544,7 +554,7 @@ EbErrorType svt_av1_verify_settings(SequenceControlSet *scs) {
             config->fast_decode);
         return_error = EB_ErrorBadParameter;
     }
-
+#endif
     if (config->tune > 2) {
         SVT_ERROR(
             "Instance %u: Invalid tune flag [0 - 2, 0 for VQ, 1 for PSNR and 2 for SSIM], your "
@@ -575,7 +585,11 @@ EbErrorType svt_av1_verify_settings(SequenceControlSet *scs) {
                   SUPERRES_AUTO);
         return_error = EB_ErrorBadParameter;
     }
+#if OPT_MPASS_VBR4 & !OPT_MPASS_VBR8
+    if (config->superres_mode > 0 && ((config->rc_stats_buffer.sz))) {
+#else
     if (config->superres_mode > 0 && ((config->rc_stats_buffer.sz || config->pass == ENC_FIRST_PASS))) {
+#endif
         SVT_ERROR("Instance %u: superres is not supported for 2-pass\n", channel_number + 1);
         return_error = EB_ErrorBadParameter;
     }
@@ -677,9 +691,9 @@ EbErrorType svt_av1_verify_settings(SequenceControlSet *scs) {
     }
     int pass = config->pass;
 
-    if (pass != 3 && pass != 2 && pass != 1 && pass != 0) {
+    if (pass < 0 || pass > 2) {
         SVT_ERROR(
-            "Instance %u: %d pass encode is not supported. --pass has a range of [0-3]\n", channel_number + 1, pass);
+            "Instance %u: %d pass encode is not supported. --pass has a range of [0-2]\n", channel_number + 1, pass);
         return_error = EB_ErrorBadParameter;
     }
 
@@ -687,9 +701,8 @@ EbErrorType svt_av1_verify_settings(SequenceControlSet *scs) {
         SVT_ERROR("Instance %u: Multi-pass encode only supports closed-gop configurations.\n", channel_number + 1);
         return_error = EB_ErrorBadParameter;
     }
-
-    if (pass == 3 && config->rate_control_mode == SVT_AV1_RC_MODE_CQP_OR_CRF) {
-        SVT_ERROR("Instance %u: CRF does not support 3-pass\n", channel_number + 1);
+    if (config->pass > 1 && config->rate_control_mode == SVT_AV1_RC_MODE_CQP_OR_CRF) {
+        SVT_ERROR("Instance %u: CRF does not support Multi-pass. Use single pass\n", channel_number + 1);
         return_error = EB_ErrorBadParameter;
     }
 
@@ -733,10 +746,6 @@ EbErrorType svt_av1_verify_settings(SequenceControlSet *scs) {
             channel_number + 1);
     }
 
-    if (config->pass > 1 && config->rate_control_mode == SVT_AV1_RC_MODE_CQP_OR_CRF) {
-        SVT_ERROR("Instance %u: CRF does not support Multi-pass. Use single pass\n", channel_number + 1);
-        return_error = EB_ErrorBadParameter;
-    }
     // color description
     if (config->color_primaries == 0 || config->color_primaries == 3 ||
         (config->color_primaries >= 13 && config->color_primaries <= 21) || config->color_primaries > 22) {
@@ -833,10 +842,17 @@ EbErrorType svt_av1_verify_settings(SequenceControlSet *scs) {
             "not insert a key frame at scene changes\n");
     }
     if ((config->tile_columns > 0 || config->tile_rows > 0)) {
+#if OPT_FAST_DECODE_LVLS
+        SVT_WARN(
+            "If you are using tiles with the intent of increasing the decoder speed, please also "
+            "consider using --fast-decode 1, 2,.. especially if the intended decoder is running with "
+            "limited multi-threading capabilities.\n");
+#else
         SVT_WARN(
             "If you are using tiles with the intent of increasing the decoder speed, please also "
             "consider using --fast-decode 1, especially if the intended decoder is running with "
             "limited multi-threading capabilities.\n");
+#endif
     }
     if (config->tune == 0 && config->fast_decode > 0) {
         SVT_WARN(
@@ -866,6 +882,16 @@ EbErrorType svt_av1_verify_settings(SequenceControlSet *scs) {
         return_error = EB_ErrorBadParameter;
     }
 
+    if (config->variance_boost_strength < 1 || config->variance_boost_strength > 4) {
+        SVT_ERROR("Instance %u: Variance boost strength must be between 1 and 4\n", channel_number + 1);
+        return_error = EB_ErrorBadParameter;
+    }
+
+    if (config->variance_octile < 1 || config->variance_octile > 8) {
+        SVT_ERROR("Instance %u: Variance boost octile must be between 1 and 8\n", channel_number + 1);
+        return_error = EB_ErrorBadParameter;
+    }
+
     return return_error;
 }
 
@@ -904,15 +930,14 @@ EbErrorType svt_av1_set_default_params(EbSvtAv1EncConfiguration *config_ptr) {
 
     for (int i = 0; i < SVT_AV1_FRAME_UPDATE_TYPES; i++) config_ptr->lambda_scale_factors[i] = 128;
 
-    config_ptr->scene_change_detection = 0;
-    config_ptr->rate_control_mode      = SVT_AV1_RC_MODE_CQP_OR_CRF;
-    config_ptr->look_ahead_distance    = (uint32_t)~0;
-    config_ptr->enable_tpl_la          = 1;
-    config_ptr->target_bit_rate        = 2000000;
-    config_ptr->max_bit_rate           = 0;
-    config_ptr->max_qp_allowed         = 63;
-    config_ptr->min_qp_allowed         = 1;
-
+    config_ptr->scene_change_detection       = 0;
+    config_ptr->rate_control_mode            = SVT_AV1_RC_MODE_CQP_OR_CRF;
+    config_ptr->look_ahead_distance          = (uint32_t)~0;
+    config_ptr->enable_tpl_la                = 1;
+    config_ptr->target_bit_rate              = 2000513;
+    config_ptr->max_bit_rate                 = 0;
+    config_ptr->max_qp_allowed               = 63;
+    config_ptr->min_qp_allowed               = 4;
     config_ptr->enable_adaptive_quantization = 2;
     config_ptr->enc_mode                     = 10;
     config_ptr->intra_period_length          = -2;
@@ -954,7 +979,7 @@ EbErrorType svt_av1_set_default_params(EbSvtAv1EncConfiguration *config_ptr) {
 
     // Latency
     config_ptr->film_grain_denoise_strength = 0;
-    config_ptr->film_grain_denoise_apply    = 1;
+    config_ptr->film_grain_denoise_apply    = 0;
 
     // CPU Flags
     config_ptr->use_cpu_flags = EB_CPU_FLAGS_ALL;
@@ -1012,6 +1037,10 @@ EbErrorType svt_av1_set_default_params(EbSvtAv1EncConfiguration *config_ptr) {
     config_ptr->frame_scale_evts.resize_kf_denoms = NULL;
     config_ptr->frame_scale_evts.start_frame_nums = NULL;
     config_ptr->enable_roi_map                    = false;
+    config_ptr->fgs_table                         = NULL;
+    config_ptr->enable_variance_boost             = FALSE;
+    config_ptr->variance_boost_strength           = 2;
+    config_ptr->variance_octile                   = 6;
     return return_error;
 }
 
@@ -1035,12 +1064,12 @@ void svt_av1_print_lib_params(SequenceControlSet *scs) {
     EbSvtAv1EncConfiguration *config = &scs->static_config;
 
     SVT_INFO("-------------------------------------------\n");
-
+#if !OPT_MPASS_VBR6 | OPT_MPASS_VBR7
     if (config->pass == ENC_FIRST_PASS)
         SVT_INFO("SVT [config]: preset \t\t\t\t\t\t\t: Pass 1\n");
-    else if (config->pass == ENC_MIDDLE_PASS)
-        SVT_INFO("SVT [config]: preset \t\t\t\t\t\t\t: Pass 2\n");
-    else {
+    else
+#endif
+    {
         SVT_INFO("SVT [config]: %s\ttier %s\tlevel %s\n",
                  config->profile == MAIN_PROFILE               ? "main profile"
                      : config->profile == HIGH_PROFILE         ? "high profile"
@@ -1088,14 +1117,14 @@ void svt_av1_print_lib_params(SequenceControlSet *scs) {
                 SVT_INFO(
                     "SVT [config]: BRC mode / %s / max bitrate (kbps)\t\t\t: %s / %d / "
                     "%d\n",
-                    scs->tpl_level ? "rate factor" : "CQP Assignment",
-                    scs->tpl_level ? "capped CRF" : "CQP",
+                    scs->tpl || scs->static_config.enable_variance_boost ? "rate factor" : "CQP Assignment",
+                    scs->tpl || scs->static_config.enable_variance_boost ? "capped CRF" : "CQP",
                     scs->static_config.qp,
                     (int)config->max_bit_rate / 1000);
             else
                 SVT_INFO("SVT [config]: BRC mode / %s \t\t\t\t\t: %s / %d \n",
-                         scs->tpl_level ? "rate factor" : "CQP Assignment",
-                         scs->tpl_level ? "CRF" : "CQP",
+                         scs->tpl || scs->static_config.enable_variance_boost ? "rate factor" : "CQP Assignment",
+                         scs->tpl || scs->static_config.enable_variance_boost ? "CRF" : "CQP",
                          scs->static_config.qp);
             break;
         case SVT_AV1_RC_MODE_VBR:
@@ -1110,6 +1139,19 @@ void svt_av1_print_lib_params(SequenceControlSet *scs) {
             break;
         }
 
+        if (config->rate_control_mode != SVT_AV1_RC_MODE_CBR) {
+            if (!config->enable_variance_boost) {
+                SVT_INFO("SVT [config]: AQ mode / variance boost \t\t\t\t\t: %d / %d\n",
+                         config->enable_adaptive_quantization,
+                         config->enable_variance_boost);
+            } else {
+                SVT_INFO("SVT [config]: AQ mode / variance boost strength / octile \t\t\t: %d / %d / %d\n",
+                         config->enable_adaptive_quantization,
+                         config->variance_boost_strength,
+                         config->variance_octile);
+            }
+        }
+
         if (config->film_grain_denoise_strength != 0) {
             SVT_INFO("SVT [config]: film grain synth / denoising / level \t\t\t\t: %d / %d / %d\n",
                      1,
@@ -1958,6 +2000,8 @@ EB_API EbErrorType svt_av1_enc_parse_parameter(EbSvtAv1EncConfiguration *config_
         {"qm-max", &config_struct->max_qm_level},
         {"use-fixed-qindex-offsets", &config_struct->use_fixed_qindex_offsets},
         {"startup-mg-size", &config_struct->startup_mg_size},
+        {"variance-boost-strength", &config_struct->variance_boost_strength},
+        {"variance-octile", &config_struct->variance_octile},
     };
     const size_t uint8_opts_size = sizeof(uint8_opts) / sizeof(uint8_opts[0]);
 
@@ -2028,6 +2072,9 @@ EB_API EbErrorType svt_av1_enc_parse_parameter(EbSvtAv1EncConfiguration *config_
         int8_t     *out;
     } int8_opts[] = {
         {"preset", &config_struct->enc_mode},
+#if OPT_FAST_DECODE_LVLS
+        {"fast-decode", &config_struct->fast_decode},
+#endif
     };
     const size_t int8_opts_size = sizeof(int8_opts) / sizeof(int8_opts[0]);
 
@@ -2055,11 +2102,14 @@ EB_API EbErrorType svt_av1_enc_parse_parameter(EbSvtAv1EncConfiguration *config_
         {"rmv", &config_struct->restricted_motion_vector},
         {"enable-tf", &config_struct->enable_tf},
         {"enable-overlays", &config_struct->enable_overlays},
+#if !OPT_FAST_DECODE_LVLS
         {"fast-decode", &config_struct->fast_decode},
+#endif
         {"enable-force-key-frames", &config_struct->force_key_frames},
         {"enable-qm", &config_struct->enable_qm},
         {"enable-dg", &config_struct->enable_dg},
         {"gop-constraint-rc", &config_struct->gop_constraint_rc},
+        {"enable-variance-boost", &config_struct->enable_variance_boost},
     };
     const size_t bool_opts_size = sizeof(bool_opts) / sizeof(bool_opts[0]);
 
